@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 This file will be invoked by python when called with th `-m` options:
 
@@ -6,7 +5,6 @@ This file will be invoked by python when called with th `-m` options:
 python -m skhep_testdata cms_hep_2012_tutorial/data.root
 ```
 """
-from __future__ import print_function
 
 import argparse
 
